@@ -205,8 +205,8 @@ class BaseLog:
             else:
                 raise ValueError('传入参数必须为字典')
         except Exception as e:
-            self.error(e)
-
+            self.error(str(e))
+10
 
 
 
